from distutils.core import setup

setup(
  name = 'pytento',
  packages = ['pytento'],
  version = '1.0.0',
  license='MIT',
  description = 'This is a staticly-typed testing framework',
  author = 'Demir Antay',
  author_email = 'demir99antay@gmail.com',
  url = 'https://github.com/demirantay/pytento',
  # download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',
  keywords = ['unit testing', 'python', 'testing', 'framework'],
  install_requires=[],
)
